<div data-quill="toolbar" data-id="{{ id }}" class="toolbar">
	<span class="ql-format-group">
		<span title="Bold" class="ql-format-button ql-bold"></span>
		<span class="ql-format-separator"></span>
		<span title="Italic" class="ql-format-button ql-italic"></span>
		<span class="ql-format-separator"></span>
		<span title="Underline" class="ql-format-button ql-underline"></span>
	</span>
	<span class="ql-format-group">
		<span title="List" class="ql-format-button ql-list"></span>
		<span class="ql-format-separator"></span>
		<span title="Bullet" class="ql-format-button ql-bullet"></span>
		<span class="ql-format-separator"></span>
	</span>
	<span class="ql-format-group">
		<span title="Link" class="ql-format-button ql-link"></span>
	</span>
</div>
